@@ -6,17 +6,17 @@
 
 #include <config-kig.h>
 
-#include "object_type.h"
 #include "circle_type.h"
 #include "conic_types.h"
 #include "cubic_type.h"
 #include "intersection_types.h"
 #include "line_type.h"
-#include "text_type.h"
+#include "object_type.h"
 #include "other_type.h"
-#include "transform_types.h"
 #include "point_type.h"
 #include "tests_type.h"
+#include "text_type.h"
+#include "transform_types.h"
 
 #ifdef KIG_ENABLE_PYTHON_SCRIPTING
 #include "../scripting/python_type.h"
@@ -33,23 +33,23 @@ ObjectTypeFactory::~ObjectTypeFactory()
 {
 }
 
-ObjectTypeFactory* ObjectTypeFactory::instance()
+ObjectTypeFactory *ObjectTypeFactory::instance()
 {
-  static ObjectTypeFactory fact;
-  return &fact;
+    static ObjectTypeFactory fact;
+    return &fact;
 }
 
-void ObjectTypeFactory::add( const ObjectType* type )
+void ObjectTypeFactory::add(const ObjectType *type)
 {
-  assert( mmap.find( std::string( type->fullName() ) ) == mmap.end() );
-  mmap[std::string( type->fullName() )] = type;
+    assert(mmap.find(std::string(type->fullName())) == mmap.end());
+    mmap[std::string(type->fullName())] = type;
 }
 
-const ObjectType* ObjectTypeFactory::find( const char* name ) const
+const ObjectType *ObjectTypeFactory::find(const char *name) const
 {
-  maptype::const_iterator i = mmap.find( std::string( name ) );
-  if ( i == mmap.end() ) return 0;
-  else return i->second;
+    maptype::const_iterator i = mmap.find(std::string(name));
+    if (i == mmap.end())
+        return nullptr;
+    else
+        return i->second;
 }
-
-
